# Generated by Django 3.2.5 on 2021-09-21 10:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('payment', '0008_alter_subscription_end_date'),
    ]

    operations = [
        migrations.AddField(
            model_name='subscription',
            name='subid',
            field=models.CharField(max_length=200, null=True, verbose_name='Subscription ID'),
        ),
    ]
