# Generated by Django 3.2.5 on 2021-07-29 11:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('payment', '0002_paymentorder_date'),
    ]

    operations = [
        migrations.AlterField(
            model_name='paymentorder',
            name='additional_info',
            field=models.JSONField(null=True, verbose_name='Entire Session Data'),
        ),
        migrations.AlterField(
            model_name='paymentorder',
            name='email',
            field=models.EmailField(max_length=254, null=True, verbose_name='Email'),
        ),
        migrations.AlterField(
            model_name='paymentorder',
            name='name',
            field=models.CharField(max_length=200, null=True, verbose_name='Name'),
        ),
        migrations.AlterField(
            model_name='paymentorder',
            name='payment_service',
            field=models.CharField(max_length=200, null=True, verbose_name='Payment Service Name'),
        ),
        migrations.AlterField(
            model_name='paymentorder',
            name='payment_success',
            field=models.BooleanField(default=False, null=True, verbose_name='Payment Success'),
        ),
        migrations.AlterField(
            model_name='paymentorder',
            name='session_id',
            field=models.CharField(max_length=200, null=True, verbose_name='Session ID'),
        ),
    ]
