# Generated by Django 3.2.5 on 2021-09-21 11:00

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('payment', '0010_auto_20210921_1055'),
    ]

    operations = [
        migrations.AlterField(
            model_name='paymentorder',
            name='name',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to=settings.AUTH_USER_MODEL, verbose_name='Name'),
        ),
    ]
