# Generated by Django 3.2.5 on 2021-09-20 13:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('payment', '0005_subscription'),
    ]

    operations = [
        migrations.AddField(
            model_name='subscription',
            name='customer_id',
            field=models.CharField(max_length=200, null=True, verbose_name='Customer ID'),
        ),
    ]
