# Generated by Django 3.2.5 on 2021-07-29 09:41

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='PaymentOrder',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=200, verbose_name='Name')),
                ('email', models.EmailField(max_length=254, verbose_name='Email')),
                ('session_id', models.CharField(max_length=200, verbose_name='Session ID')),
                ('payment_success', models.BooleanField(default=False, verbose_name='Payment Success')),
                ('payment_service', models.CharField(max_length=200, verbose_name='Payment Service Name')),
                ('additional_info', models.JSONField(verbose_name='Entire Session Data')),
            ],
        ),
    ]
