# Generated by Django 3.2.5 on 2021-07-29 11:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('payment', '0003_auto_20210729_1132'),
    ]

    operations = [
        migrations.AlterField(
            model_name='paymentorder',
            name='additional_info',
            field=models.TextField(null=True, verbose_name='Entire Session Data'),
        ),
    ]
