# Generated by Django 3.2.5 on 2021-09-21 09:47

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('payment', '0006_subscription_customer_id'),
    ]

    operations = [
        migrations.AddField(
            model_name='subscription',
            name='active',
            field=models.BooleanField(default=False, verbose_name='Subscription Active'),
        ),
        migrations.AddField(
            model_name='subscription',
            name='end_date',
            field=models.DateTimeField(blank=True, null=True, verbose_name='Subscription End Date (if cancelted by User)'),
        ),
        migrations.AlterField(
            model_name='subscription',
            name='date',
            field=models.DateTimeField(null=True, verbose_name='Subscription Start Date'),
        ),
    ]
